<?php
/**
 * Clarice Acervo functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Clarice Acervo
 */

if ( ! function_exists( 'clarice_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function clarice_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Clarice Acervo, use a find and replace
		 * to change 'clarice' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'clarice', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'menu-1' => esc_html__( 'Primary', 'clarice' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'clarice_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
	}
endif;
add_action( 'after_setup_theme', 'clarice_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function clarice_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'clarice_content_width', 640 );
}
add_action( 'after_setup_theme', 'clarice_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function clarice_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'clarice' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'clarice' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Seletor de idiomas', 'clarice' ),
		'id'            => 'header-switcher',
		'description'   => esc_html__( 'Adicionar seletor de idiomas aqui.', 'clarice' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Rodapé', 'clarice' ),
		'id'            => 'footer',
		'description'   => esc_html__( 'Conteúdo do rodapé.', 'clarice' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Infos legais', 'clarice' ),
		'id'            => 'legal',
		'description'   => esc_html__( 'Conteúdo legal abaixo do rodapé.', 'clarice' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'clarice_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function clarice_scripts() {
	wp_enqueue_style( 'clarice-style', get_stylesheet_uri() );
	
	wp_enqueue_script( 'clarice-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '', true );
	
	wp_enqueue_script( 'clarice-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true );
	

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	if ( is_post_type_archive( 'livro' ) || is_singular( 'acervo' ) ) {

		wp_enqueue_script( 'clarice-slick-lb', '//cdnjs.cloudflare.com/ajax/libs/slick-lightbox/0.2.12/slick-lightbox.min.js', array(), '', true );
		
		wp_enqueue_style( 'clarice-slick-lb', '//cdnjs.cloudflare.com/ajax/libs/slick-lightbox/0.2.12/slick-lightbox.css' );
		
		wp_enqueue_script( 'clarice-slick', '//cdn.jsdelivr.net/npm/slick-carousel@1.8.1/slick/slick.min.js', array(), '', true );
		
		wp_enqueue_style( 'clarice-slick', '//cdn.jsdelivr.net/npm/slick-carousel@1.8.1/slick/slick.css' );
	}
	
	wp_enqueue_script( 'jquery-ui-accordion' );
	
	wp_enqueue_script( 'clarice-scripts', get_template_directory_uri() . '/js/clarice.js', array(), '0.9', true );
}
add_action( 'wp_enqueue_scripts', 'clarice_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

/**
 * ACF Blocks
 */
require get_template_directory() . '/inc/blocks.php';

// remove wpml css
define('ICL_DONT_LOAD_LANGUAGE_SELECTOR_CSS', true);

show_admin_bar(false);

remove_filter ('acf_the_content', 'wpautop');

// add_action('wp_print_styles', 'remove_sf_styles', 100);
// function remove_sf_styles(){
    
// 	wp_dequeue_style( 'search-filter-plugin-styles' );
// }

add_action( 'pre_get_posts', 'clarice_livros' );

function clarice_livros( $query ) {
    
    if ( ! is_admin() && $query->is_main_query() ) {
    
        if ( is_post_type_archive( 'livro' ) ) {
            
            $query->set('posts_per_page', -1);
			$query->set('meta_key', 'ano');
			$query->set('orderby', 'meta_value');
			$query->set('order'	, 'ASC');
    
        }
    }
}

/**
 * Gutenberg scripts and styles
 * @link https://www.billerickson.net/block-styles-in-gutenberg/
 */
function be_gutenberg_scripts() {

	wp_enqueue_script(
		'be-editor', 
		get_stylesheet_directory_uri() . '/js/editor.js', 
		array( 'wp-blocks', 'wp-dom' ), 
		filemtime( get_stylesheet_directory() . '/js/editor.js' ),
		true
	);
}
add_action( 'enqueue_block_editor_assets', 'be_gutenberg_scripts' );

// Set Featured Image from ACF Field
function acf_set_featured_image( $value, $post_id, $field ) {
    if($value != ''){
        update_post_meta($post_id, '_thumbnail_id', $value);
    } else {
        if ( has_post_thumbnail() ) {
            delete_post_thumbnail( $post_id);
        } 
    }
    return $value;
}
add_filter('acf/update_value/name=imagem_docs', 'acf_set_featured_image', 10, 3);

if(ICL_LANGUAGE_CODE=='en') {
	$title = 'Document name';
	$content = 'Description (will be reviewed)';
}
if(ICL_LANGUAGE_CODE=='pt-br') {
	$title = 'Nome do documento';
	$content = 'Descrição (passará por revisão)';
}

// Change Title Lable
function change_title_label( $field ) {


	if(ICL_LANGUAGE_CODE=='en') {
		$title = 'Document name';
	}
	if(ICL_LANGUAGE_CODE=='pt-br') {
		$title = 'Nome do documento';
	}
    $field['label'] = $title;
    return $field;
}
add_filter('acf/load_field/name=_post_title', 'change_title_label');
// Change Content Label 
function change_content_label( $field ) {


	if(ICL_LANGUAGE_CODE=='en') {
		$content = 'Description (will be reviewed)';
	}
	if(ICL_LANGUAGE_CODE=='pt-br') {
		$content = 'Descrição (passará por revisão)';
	}
    $field['label'] = $content;
    return $field;
}
add_filter('acf/load_field/name=_post_content', 'change_content_label');

// Change Post Content Type
add_filter( 'acf/get_valid_field', 'change_post_content_type');
function change_post_content_type( $field ) { 
    if($field['type'] == 'wysiwyg') {
        $field['tabs'] = 'visual';
        $field['toolbar'] = 'basic';
        $field['media_upload'] = 0;
    }
    return $field;
}

add_action('acf/save_post', 'new_doc_email');

function new_doc_email( $post_id ) {

	if( get_post_type($post_id) !== 'sobre' && get_post_status($post_id) == 'draft' ) {
		return;
	}

	if( is_admin() ) {
		return;
	}

	$post_title = get_the_title( $post_id );
	$post_url 	= get_permalink( $post_id );
	$subject 	= "[Clarice Lispector] Novo documento recebido";
	$message 	= "Por favor, revise o post enviado pelo link abaixo:\n\n";
	$message   .= $post_title . ": " . home_url(). "/wp-admin/post.php?post=".$post_id."&action=edit";

	$administrators 	= get_users(array(
		'role'	=> 'administrator'
	));

	foreach ($administrators as &$administrator) {
		wp_mail( $administrator->data->user_email, $subject, $message );
	}

}

// Conditionally don't load the Media Library tab/ content
function remove_medialibrary_tab($strings) {
	if ( !current_user_can( 'manage_options' ) ) {
		unset($strings["mediaLibraryTitle"]);
		return $strings;
	} else {
		return $strings;
	}
}
add_filter('media_view_strings','remove_medialibrary_tab');

// Conditionally don't run the Media Library's initializing AJAX
function restrict_non_Admins(){
	if( !current_user_can( 'manage_options' ) ){
		exit;
	}
}
add_action('wp_ajax_query-attachments','restrict_non_Admins',1);
add_action('wp_ajax_nopriv_query-attachments','restrict_non_Admins',1);

add_filter( 'get_the_archive_title', 'clarice_archive_title' );
/**
 * Remove archive labels.
 * 
 * @param  string $title Current archive title to be displayed.
 * @return string        Modified archive title to be displayed.
 */
function clarice_archive_title( $title ) {
    if ( is_category() ) {
        $title = single_cat_title( '', false );
    } elseif ( is_tag() ) {
        $title = single_tag_title( '', false );
    } elseif ( is_author() ) {
        $title = '<span class="vcard">' . get_the_author() . '</span>';
    } elseif ( is_post_type_archive() ) {
        $title = post_type_archive_title( '', false );
    } elseif ( is_tax() ) {
        $title = single_term_title( '', false );
    }

    return $title;
}

// renomear posts
function clarice_change_post_label() {
    global $menu;
    global $submenu;
    $menu[5][0] = 'Postagens';
    $submenu['edit.php'][5][0] = 'Postagens';
    $submenu['edit.php'][10][0] = 'Adicionar postagem';
    $submenu['edit.php'][16][0] = 'Tags de postagens';
}
function clarice_change_post_object() {
    global $wp_post_types;
    $labels = &$wp_post_types['post']->labels;
    $labels->name = 'Postagens';
    $labels->singular_name = 'Postagem';
    $labels->add_new = 'Adicionar postagem';
    $labels->add_new_item = 'Adicionar postagem';
    $labels->edit_item = 'Editar postagem';
    $labels->new_item = 'Postagem';
    $labels->view_item = 'Ver postagem';
    $labels->search_items = 'Buscar postagens';
    $labels->not_found = 'Nenhuma postagem encontrada';
    $labels->not_found_in_trash = 'Nenhuma postagem encontrada na lixeira';
    $labels->all_items = 'Todas as postagens';
    $labels->menu_name = 'Postagens';
    $labels->name_admin_bar = 'Postagens';
}
 
add_action( 'admin_menu', 'clarice_change_post_label' );
add_action( 'init', 'clarice_change_post_object' );

function infos_RSS($content) {
	global $post;
	if ( has_post_thumbnail( $post->ID ) ){
		$content = '<div class="imagem_artigo"><img src="' . get_the_post_thumbnail_url($post->ID,'full') . '"/></div><div class="autor_artigo">' . get_field('autor') . '</div><div class="conteudo_artigo">' . $content.'</div><div class="descricao_artigo">' . get_the_excerpt() . '</div>';
	}
	return $content;
}
add_filter('the_excerpt_rss', 'infos_RSS');
add_filter('the_content_feed', 'infos_RSS');